==========
 httptest
==========

httptest is a real live HTTP server to use in tests. See httptest.py for more
information.


* The 0.0.x version range supports python 2.7 and 3 (see the 0.0.x branch)
* Versions 1.0.0 and above only support python 3
